fn build_static_mut_checks<'tcx>(
tcx: TyCtxt<'tcx>,
def_id: DefId,
) -> Vec<(Checkpoint<'tcx>, Vec<Property<'tcx>>)>Expand description
Build (pseudo-checkpoint, properties) pairs for every static mut access in the target function.
fn build_static_mut_checks<'tcx>(
tcx: TyCtxt<'tcx>,
def_id: DefId,
) -> Vec<(Checkpoint<'tcx>, Vec<Property<'tcx>>)>Build (pseudo-checkpoint, properties) pairs for every static mut access in the target function.