fn marker_trait_kind(
tcx: TyCtxt<'_>,
trait_def_id: DefId,
) -> Option<MarkerTraitKind>Expand description
Resolve whether an unsafe impl is implementing the Send/Sync marker trait.
fn marker_trait_kind(
tcx: TyCtxt<'_>,
trait_def_id: DefId,
) -> Option<MarkerTraitKind>Resolve whether an unsafe impl is implementing the Send/Sync marker trait.