pub struct PrepareTargets<'tcx> {
tcx: TyCtxt<'tcx>,
}Expand description
Analysis pass that finds all targets annotated with #[rapx::verify].
Fields
tcx: TyCtxt<'tcx>Implementations
Sourceimpl<'tcx> PrepareTargets<'tcx>
impl<'tcx> PrepareTargets<'tcx>
Sourcefn log_function_target(
&self,
target: &FunctionTarget<'tcx>,
nested_under_struct: bool,
)
fn log_function_target( &self, target: &FunctionTarget<'tcx>, nested_under_struct: bool, )
Logs one function target and all contracts collected from its unsafe callees.
Sourcefn log_function_paths(&self, target: &FunctionTarget<'tcx>)
fn log_function_paths(&self, target: &FunctionTarget<'tcx>)
Logs unsafe callsites and loop-aware path skeletons for one target.