pub struct StructTarget<'tcx> {
pub def_id: DefId,
pub invariants: StructInvariants<'tcx>,
pub function_targets: Vec<FunctionTarget<'tcx>>,
}Expand description
Collected verification data for a struct that owns methods marked with #[rapx::verify].
Fields
def_id: DefIdStruct that owns one or more methods selected as targets to verify.
invariants: StructInvariants<'tcx>Parsed invariant contracts attached to the struct.
function_targets: Vec<FunctionTarget<'tcx>>Methods of this struct selected as targets to verify.