pub struct FunctionTarget<'tcx> {
pub def_id: DefId,
pub owner_struct_def_id: Option<DefId>,
pub callee_requires: HashMap<DefId, FnContracts<'tcx>>,
}Expand description
Collected verification data for a function annotated with #[rapx::verify].
Fields
def_id: DefIdFunction marked with #[rapx::verify] and selected as a target to verify.
owner_struct_def_id: Option<DefId>Owning struct definition when this target to verify is an associated method.
callee_requires: HashMap<DefId, FnContracts<'tcx>>Parsed requires contracts for each unsafe callee reachable from this target.